@@ -28,6 +28,7 @@ typedef struct {
     unsigned Size;
 }Section_t;
 
+#define MAX_DATE_COPIES 10
 
 //--------------------------------------------------------------------------
 // This structure stores Exif header image elements in a simple manner
@@ -60,7 +61,8 @@ typedef struct {
     unsigned char * ThumbnailPointer;  // Pointer at the thumbnail
     unsigned ThumbnailSize;     // Size of thumbnail.
 
-    char * DatePointer;
+    char * DateTimePointers[MAX_DATE_COPIES];
+    int  numDateTimeTags;
 }ImageInfo_t;
 
 
